@@ -1,4 +1,4 @@
-"""
+'''
 # aws-cloudfront-apigateway module
 
 <!--BEGIN STABILITY BANNER-->---
@@ -110,7 +110,7 @@ Out of the box implementation of the Construct without any override will set the
 
 
 © Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-"""
+'''
 import abc
 import builtins
 import datetime
@@ -144,7 +144,7 @@ class CloudFrontToApiGateway(
         cloud_front_distribution_props: typing.Any = None,
         insert_http_security_headers: typing.Optional[builtins.bool] = None,
     ) -> None:
-        """
+        '''
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
         :param existing_api_gateway_obj: Existing instance of api.RestApi object. Default: - None
@@ -154,7 +154,7 @@ class CloudFrontToApiGateway(
         :access: public
         :since: 0.8.0
         :summary: Constructs a new instance of the CloudFrontToApiGateway class.
-        """
+        '''
         props = CloudFrontToApiGatewayProps(
             existing_api_gateway_obj=existing_api_gateway_obj,
             cloud_front_distribution_props=cloud_front_distribution_props,
@@ -203,13 +203,13 @@ class CloudFrontToApiGatewayProps:
         cloud_front_distribution_props: typing.Any = None,
         insert_http_security_headers: typing.Optional[builtins.bool] = None,
     ) -> None:
-        """
+        '''
         :param existing_api_gateway_obj: Existing instance of api.RestApi object. Default: - None
         :param cloud_front_distribution_props: Optional user provided props to override the default props. Default: - Default props are used
         :param insert_http_security_headers: Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront. Default: - true
 
         :summary: The properties for the CloudFrontToApiGateway Construct
-        """
+        '''
         self._values: typing.Dict[str, typing.Any] = {
             "existing_api_gateway_obj": existing_api_gateway_obj,
         }
@@ -220,29 +220,29 @@ class CloudFrontToApiGatewayProps:
 
     @builtins.property
     def existing_api_gateway_obj(self) -> aws_cdk.aws_apigateway.RestApi:
-        """Existing instance of api.RestApi object.
+        '''Existing instance of api.RestApi object.
 
         :default: - None
-        """
+        '''
         result = self._values.get("existing_api_gateway_obj")
         assert result is not None, "Required property 'existing_api_gateway_obj' is missing"
         return typing.cast(aws_cdk.aws_apigateway.RestApi, result)
 
     @builtins.property
     def cloud_front_distribution_props(self) -> typing.Any:
-        """Optional user provided props to override the default props.
+        '''Optional user provided props to override the default props.
 
         :default: - Default props are used
-        """
+        '''
         result = self._values.get("cloud_front_distribution_props")
         return typing.cast(typing.Any, result)
 
     @builtins.property
     def insert_http_security_headers(self) -> typing.Optional[builtins.bool]:
-        """Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront.
+        '''Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront.
 
         :default: - true
-        """
+        '''
         result = self._values.get("insert_http_security_headers")
         return typing.cast(typing.Optional[builtins.bool], result)
 
